==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.customerrental_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.customerrental_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link CustomerRental }
     * 
     */
    public CustomerRental createCustomerRental() {
        return new CustomerRental();
    }

    /**
     * Create an instance of {@link RentalDetails }
     * 
     */
    public RentalDetails createRentalDetails() {
        return new RentalDetails();
    }

    /**
     * Create an instance of {@link IssueDetails }
     * 
     */
    public IssueDetails createIssueDetails() {
        return new IssueDetails();
    }

    /**
     * Create an instance of {@link ReturnDetails }
     * 
     */
    public ReturnDetails createReturnDetails() {
        return new ReturnDetails();
    }

    /**
     * Create an instance of {@link InvoicingDetails }
     * 
     */
    public InvoicingDetails createInvoicingDetails() {
        return new InvoicingDetails();
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.customerrental_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.customerrental_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link CustomerRental }
     * 
     * @return
     *     the new instance of {@link CustomerRental }
     */
    public CustomerRental createCustomerRental() {
        return new CustomerRental();
    }

    /**
     * Create an instance of {@link RentalDetails }
     * 
     * @return
     *     the new instance of {@link RentalDetails }
     */
    public RentalDetails createRentalDetails() {
        return new RentalDetails();
    }

    /**
     * Create an instance of {@link IssueDetails }
     * 
     * @return
     *     the new instance of {@link IssueDetails }
     */
    public IssueDetails createIssueDetails() {
        return new IssueDetails();
    }

    /**
     * Create an instance of {@link ReturnDetails }
     * 
     * @return
     *     the new instance of {@link ReturnDetails }
     */
    public ReturnDetails createReturnDetails() {
        return new ReturnDetails();
    }

    /**
     * Create an instance of {@link InvoicingDetails }
     * 
     * @return
     *     the new instance of {@link InvoicingDetails }
     */
    public InvoicingDetails createInvoicingDetails() {
        return new InvoicingDetails();
    }

}
